#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_BITWISE_XOR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_BITWISE_XOR_HPP_INCLUDED

#include <nt2/operator/include/functions/scalar/bitwise_xor.hpp>

#endif
